=== modified file 'drizzled/session.cc'
--- drizzled/session.cc	2008-12-15 17:17:31 +0000
+++ drizzled/session.cc	2008-12-16 06:44:47 +0000
@@ -1535,8 +1535,6 @@
   if ((uint) strlen(exchange->file_name) + NAME_LEN >= FN_REFLEN)
     strncpy(path,exchange->file_name,FN_REFLEN-1);
 
-  if ((file= create_file(session, path, exchange, &cache)) < 0)
-    return 1;
   /* Check if there is any blobs in data */
   {
     List_iterator_fast<Item> li(list);
@@ -1578,12 +1576,12 @@
       (exchange->opt_enclosed && non_string_results &&
        field_term_length && strchr(NUMERIC_CHARS, field_term_char)))
   {
-    push_warning(session, DRIZZLE_ERROR::WARN_LEVEL_WARN,
-                 ER_AMBIGUOUS_FIELD_TERM, ER(ER_AMBIGUOUS_FIELD_TERM));
-    is_ambiguous_field_term= true;
+    my_error(ER_AMBIGUOUS_FIELD_TERM, MYF(0));
+    return 1;
   }
-  else
-    is_ambiguous_field_term= false;
+
+  if ((file= create_file(session, path, exchange, &cache)) < 0)
+    return 1;
 
   return 0;
 }

=== modified file 'drizzled/sql_load.cc'
--- drizzled/sql_load.cc	2008-12-09 05:50:07 +0000
+++ drizzled/sql_load.cc	2008-12-16 06:44:47 +0000
@@ -280,7 +280,10 @@
 
       struct stat stat_info;
       if (stat(name,&stat_info))
+      {
+        my_error(ER_FILE_NOT_FOUND, MYF(0), name, errno);
 	return(true);
+      }
 
       // if we are not in slave thread, the file must be:
       if (!session->slave_thread &&
@@ -296,7 +299,10 @@
 	is_fifo = 1;
     }
     if ((file=my_open(name,O_RDONLY,MYF(MY_WME))) < 0)
+    {
+      my_error(ER_CANT_OPEN_FILE, MYF(0), my_errno);
       return(true);
+    }
   }
 
   COPY_INFO info;

=== renamed file 'tests/suite/broken/r/outfile_loaddata.result' => 'tests/r/outfile_loaddata.result'
--- tests/suite/broken/r/outfile_loaddata.result	2008-06-25 05:29:13 +0000
+++ tests/r/outfile_loaddata.result	2008-12-16 06:44:47 +0000
@@ -4,23 +4,9 @@
 #
 CREATE TABLE t1 (i1 int, i2 int, c1 VARCHAR(256), c2 VARCHAR(256));
 INSERT INTO t1 VALUES (101, 202, '-r-', '=raker=');
-# FIELDS TERMINATED BY 'raker', warning:
+# FIELDS TERMINATED BY 'raker', error:
 SELECT * INTO OUTFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' FIELDS TERMINATED BY 'raker' FROM t1;
-Warnings:
-Warning	1475	First character of the FIELDS TERMINATED string is ambiguous; please use non-optional and non-empty FIELDS ENCLOSED BY
-SELECT LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug31663.txt');
-LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug31663.txt')
-101raker202raker-r-raker=raker=
-
-CREATE TABLE t2 SELECT * FROM t1;
-LOAD DATA INFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' INTO TABLE t2 FIELDS TERMINATED BY 'raker';
-Warnings:
-Warning	1262	Row 1 was truncated; it contained more data than there were input columns
-SELECT * FROM t2;
-i1	i2	c1	c2
-101	202	-r-	=raker=
-101	202	-r-	=
-DROP TABLE t2;
+ERROR HY000: First character of the FIELDS TERMINATED string is ambiguous; please use non-optional and non-empty FIELDS ENCLOSED BY
 # Only numeric fields, FIELDS TERMINATED BY 'r', no warnings:
 SELECT i1, i2 INTO OUTFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' FIELDS TERMINATED BY 'r' FROM t1;
 SELECT LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug31663.txt');
@@ -36,37 +22,13 @@
 DROP TABLE t2;
 # FIELDS TERMINATED BY '0', warning:
 SELECT * INTO OUTFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' FIELDS TERMINATED BY '0' FROM t1;
-Warnings:
-Warning	1475	First character of the FIELDS TERMINATED string is ambiguous; please use non-optional and non-empty FIELDS ENCLOSED BY
-SELECT LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug31663.txt');
-LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug31663.txt')
-10102020-r-0=raker=
-
-CREATE TABLE t2 SELECT * FROM t1;
-LOAD DATA INFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' INTO TABLE t2 FIELDS TERMINATED BY '0';
-Warnings:
-Warning	1262	Row 1 was truncated; it contained more data than there were input columns
-SELECT * FROM t2;
-i1	i2	c1	c2
-101	202	-r-	=raker=
-1	1	2	2
-DROP TABLE t2;
+ERROR HY000: First character of the FIELDS TERMINATED string is ambiguous; please use non-optional and non-empty FIELDS ENCLOSED BY
 # FIELDS OPTIONALLY ENCLOSED BY '"' TERMINATED BY '0', warning:
 SELECT * INTO OUTFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' FIELDS OPTIONALLY ENCLOSED BY '"' TERMINATED BY '0' FROM t1;
-Warnings:
-Warning	1475	First character of the FIELDS TERMINATED string is ambiguous; please use non-optional and non-empty FIELDS ENCLOSED BY
-SELECT LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug31663.txt');
-LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug31663.txt')
-10102020"-r-"0"=raker="
-
+ERROR HY000: First character of the FIELDS TERMINATED string is ambiguous; please use non-optional and non-empty FIELDS ENCLOSED BY
 CREATE TABLE t2 SELECT * FROM t1;
 LOAD DATA INFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' INTO TABLE t2 FIELDS OPTIONALLY ENCLOSED BY '"' TERMINATED BY '0';
-Warnings:
-Warning	1262	Row 1 was truncated; it contained more data than there were input columns
-SELECT * FROM t2;
-i1	i2	c1	c2
-101	202	-r-	=raker=
-1	1	2	2
+ERROR HY000: Can't find file: 'MYSQLTEST_VARDIR/tmp/bug31663.txt' (errno: 2)
 DROP TABLE t2;
 # Only string fields, FIELDS OPTIONALLY ENCLOSED BY '"' TERMINATED BY '0', no warnings:
 SELECT c1, c2 INTO OUTFILE 'MYSQLTEST_VARDIR/tmp/bug31663.txt' FIELDS OPTIONALLY ENCLOSED BY '"' TERMINATED BY '0' FROM t1;
@@ -85,19 +47,4 @@
 #
 # Bug#32533: SELECT INTO OUTFILE never escapes multibyte character
 #
-CREATE TABLE t1 (c1 VARCHAR(256));
-INSERT INTO t1 VALUES (0xC3);
-SELECT HEX(c1) FROM t1;
-HEX(c1)
-C3
-SELECT * INTO OUTFILE 'MYSQLTEST_VARDIR/tmp/bug32533.txt' FIELDS ENCLOSED BY 0xC3 FROM t1;
-TRUNCATE t1;
-SELECT HEX(LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug32533.txt'));
-HEX(LOAD_FILE('MYSQLTEST_VARDIR/tmp/bug32533.txt'))
-C35CC3C30A
-LOAD DATA INFILE 'MYSQLTEST_VARDIR/tmp/bug32533.txt' INTO TABLE t1 FIELDS ENCLOSED BY 0xC3;
-SELECT HEX(c1) FROM t1;
-HEX(c1)
-C3
-DROP TABLE t1;
 # End of 5.0 tests.

=== renamed file 'tests/suite/broken/t/outfile_loaddata.test' => 'tests/t/outfile_loaddata.test'
--- tests/suite/broken/t/outfile_loaddata.test	2008-06-25 05:29:13 +0000
+++ tests/t/outfile_loaddata.test	2008-12-16 06:44:47 +0000
@@ -11,18 +11,11 @@
 
 --let $fields=*
 --let $clauses=FIELDS TERMINATED BY 'raker'
---echo # $clauses, warning:
+--echo # $clauses, error:
 
 --replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
+--error ER_AMBIGUOUS_FIELD_TERM
 --eval SELECT $fields INTO OUTFILE '$MYSQLTEST_VARDIR/tmp/bug31663.txt' $clauses FROM t1
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval SELECT LOAD_FILE('$MYSQLTEST_VARDIR/tmp/bug31663.txt')
---eval CREATE TABLE t2 SELECT $fields FROM t1
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval LOAD DATA INFILE '$MYSQLTEST_VARDIR/tmp/bug31663.txt' INTO TABLE t2 $clauses
---eval SELECT $fields FROM t2
---remove_file $MYSQLTEST_VARDIR/tmp/bug31663.txt
-DROP TABLE t2;
 
 --let $fields=i1, i2
 --let $clauses=FIELDS TERMINATED BY 'r'
@@ -44,29 +37,22 @@
 --echo # $clauses, warning:
 
 --replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
+--error ER_AMBIGUOUS_FIELD_TERM
 --eval SELECT $fields INTO OUTFILE '$MYSQLTEST_VARDIR/tmp/bug31663.txt' $clauses FROM t1
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval SELECT LOAD_FILE('$MYSQLTEST_VARDIR/tmp/bug31663.txt')
---eval CREATE TABLE t2 SELECT $fields FROM t1
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval LOAD DATA INFILE '$MYSQLTEST_VARDIR/tmp/bug31663.txt' INTO TABLE t2 $clauses
---eval SELECT $fields FROM t2
---remove_file $MYSQLTEST_VARDIR/tmp/bug31663.txt
-DROP TABLE t2;
 
 --let $fields=*
 --let $clauses=FIELDS OPTIONALLY ENCLOSED BY '"' TERMINATED BY '0'
 --echo # $clauses, warning:
 
 --replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
+--error ER_AMBIGUOUS_FIELD_TERM
 --eval SELECT $fields INTO OUTFILE '$MYSQLTEST_VARDIR/tmp/bug31663.txt' $clauses FROM t1
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval SELECT LOAD_FILE('$MYSQLTEST_VARDIR/tmp/bug31663.txt')
+
+# Drizzle bug (not filed, fixed): assert on file not found
 --eval CREATE TABLE t2 SELECT $fields FROM t1
 --replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
+--error ER_FILE_NOT_FOUND
 --eval LOAD DATA INFILE '$MYSQLTEST_VARDIR/tmp/bug31663.txt' INTO TABLE t2 $clauses
---eval SELECT $fields FROM t2
---remove_file $MYSQLTEST_VARDIR/tmp/bug31663.txt
 DROP TABLE t2;
 
 --let $fields=c1, c2
@@ -90,24 +76,26 @@
 --echo # Bug#32533: SELECT INTO OUTFILE never escapes multibyte character
 --echo #
 
-CREATE TABLE t1 (c1 VARCHAR(256));
-INSERT INTO t1 VALUES (0xC3);
-SELECT HEX(c1) FROM t1;
-
---let $file=$MYSQLTEST_VARDIR/tmp/bug32533.txt
-
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval SELECT * INTO OUTFILE '$file' FIELDS ENCLOSED BY 0xC3 FROM t1
-TRUNCATE t1;
-
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval SELECT HEX(LOAD_FILE('$file'))
-
---replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
---eval LOAD DATA INFILE '$file' INTO TABLE t1 FIELDS ENCLOSED BY 0xC3
-SELECT HEX(c1) FROM t1;
-
---remove_file $file
-DROP TABLE t1;
+# Disabled due to  https://bugs.launchpad.net/mysql-server/+bug/308457
+
+#CREATE TABLE t1 (c1 VARCHAR(256));
+#INSERT INTO t1 (c1) VALUES ('☠');
+#SELECT HEX(c1) FROM t1;
+
+#--let $file=$MYSQLTEST_VARDIR/tmp/bug32533.txt
+
+#--replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
+#--eval SELECT * INTO OUTFILE '$file' FIELDS ENCLOSED BY '☢' FROM t1
+#TRUNCATE t1;
+
+#--replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
+#--eval SELECT HEX(LOAD_FILE('$file'))
+
+#--replace_result $MYSQLTEST_VARDIR MYSQLTEST_VARDIR
+#--eval LOAD DATA INFILE '$file' INTO TABLE t1 FIELDS ENCLOSED BY '☢'
+#SELECT HEX(c1) FROM t1;
+
+#--remove_file $file
+#DROP TABLE t1;
 
 --echo # End of 5.0 tests.

